@@ -29,6 +29,96 @@ ctypes.windll.kernel32.OpenProcess.restype = HANDLE
 ctypes.windll.kernel32.VirtualAllocEx.restype = LPVOID
 
 
+def bytes_from_short(value: int) -> bytes:
+    """Возвращает byte представление short значения.
+
+    Return byte representation of short value.
+    """
+
+    return struct.pack("<h", value)
+
+
+def bytes_from_ushort(value: int) -> bytes:
+    """Возвращает byte представление ushort значения.
+
+    Return byte representation of ushort value.
+    """
+
+    return struct.pack("<H", value)
+
+
+def bytes_from_int(value: int) -> bytes:
+    """Возвращает byte представление int значения.
+
+    Return byte representation of int value.
+    """
+
+    return struct.pack("<i", value)
+
+
+def bytes_from_uint(value: int) -> bytes:
+    """Возвращает byte представление uint значения.
+
+    Return byte representation of uint value.
+    """
+
+    return struct.pack("<I", value)
+
+
+def bytes_from_long(value: int) -> bytes:
+    """Возвращает byte представление long значения.
+
+    Return byte representation of long value.
+    """
+
+    return struct.pack("<l", value)
+
+
+def bytes_from_ulong(value: int) -> bytes:
+    """Возвращает byte представление ulong значения.
+
+    Return byte representation of ulong value.
+    """
+
+    return struct.pack("<L", value)
+
+
+def bytes_from_longlong(value: int) -> bytes:
+    """Возвращает byte представление longlong значения.
+
+    Return byte representation of longlong value.
+    """
+
+    return struct.pack("<q", value)
+
+
+def bytes_from_ulonglong(value: int) -> bytes:
+    """Возвращает byte представление ulonglong значения.
+
+    Return byte representation of ulonglong value.
+    """
+
+    return struct.pack("<Q", value)
+
+
+def bytes_from_float(value: float) -> bytes:
+    """Возвращает byte представление float значения.
+
+    Return byte representation of float value.
+    """
+
+    return struct.pack("<f", value)
+
+
+def bytes_from_double(value: float) -> bytes:
+    """Возвращает byte представление double значения.
+
+    Return byte representation of double value.
+    """
+
+    return struct.pack("<d", value)
+
+
 def heximate_bytes(bytearray: bytes) -> str:
     r"""Возвращает массив байтов в ввиде строчного паттерна в стиле Cheat Engine.
 
@@ -333,7 +423,7 @@ class TrampolineHook:
         else:
             self.__process.write_bytes(self.__instruction_address, self.hook_bytecode)
 
-    def insert_bytecode(self, bytecode: str) -> None:
+    def insert_bytecode(self, bytecode: bytes) -> None:
         """Подставляет данный байткод перед оригинальным кодом.
 
         Instern given bytecode before the original code.
@@ -348,8 +438,7 @@ class TrampolineHook:
         >>> health_hook.insert_bytecode("C7 86 E4 03 00 00 39 05 00 00")
 
         """
-        insert_bytecode = bytecode.strip().split(" ")
-        insert_bytecode = bytes.fromhex("".join(insert_bytecode))
+        insert_bytecode = bytecode
         self.hook_bytecode = insert_bytecode + self.original_code + self.__backward__jump
         self.__process.write_bytes(self.alloc, self.hook_bytecode)
 
